@@ -514,11 +514,11 @@ int fgetconv (FGETCONV *_fc)
   return EOF;
 }
 
-void fgetconv_close (FGETCONV *_fc)
+void fgetconv_close (FGETCONV **_fc)
 {
-  struct fgetconv_s *fc = (struct fgetconv_s *)_fc;
+  struct fgetconv_s *fc = (struct fgetconv_s *) *_fc;
 
   if (fc->cd != (iconv_t)-1)
     iconv_close (fc->cd);
-  free (fc);
+  safe_free (_fc);
 }
