@@ -876,6 +876,12 @@ int mutt_index_menu (void)
 	 * The following operations can be performed inside of the pager.
 	 */
 
+#ifdef USE_IMAP
+      case OP_MAIN_IMAP_FETCH:
+      	ImapLastCheck = 0;
+        break;
+#endif
+      
       case OP_MAIN_SYNC_FOLDER:
 
 	CHECK_MSGCOUNT;
@@ -941,7 +947,7 @@ int mutt_index_menu (void)
           cp = _("Open mailbox");
 
 	buf[0] = '\0';
-	mutt_buffy (buf);
+	mutt_buffy (buf, sizeof (buf));
 
 	if (mutt_enter_fname (cp, buf, sizeof (buf), &menu->redraw, 1) == -1)
 	  break;
