@@ -84,6 +84,9 @@ struct binding_t OpMain[] = {
   { "group-reply",		OP_GROUP_REPLY,			"g" },
 #ifdef USE_POP
   { "fetch-mail",		OP_MAIN_FETCH_MAIL,		"G" },
+#endif
+#ifdef USE_IMAP
+  { "imap-fetch-mail",		OP_MAIN_IMAP_FETCH,		NULL },
 #endif
   { "display-toggle-weed",		OP_DISPLAY_HEADERS,		"h" },
   { "next-undeleted",		OP_MAIN_NEXT_UNDELETED,		"j" },
@@ -160,6 +163,9 @@ struct binding_t OpPager[] = {
   { "forward-message",	OP_FORWARD_MESSAGE,		"f" },
   { "flag-message",	OP_FLAG_MESSAGE,		"F" },
   { "group-reply",	OP_GROUP_REPLY,			"g" },
+#ifdef USE_IMAP
+  { "imap-fetch-mail",  OP_MAIN_IMAP_FETCH,		NULL },
+#endif
   { "display-toggle-weed",	OP_DISPLAY_HEADERS,		"h" },
   { "next-undeleted",	OP_MAIN_NEXT_UNDELETED,		"j" },
   { "next-entry",	OP_NEXT_ENTRY,			"J" },
@@ -236,7 +242,7 @@ struct binding_t OpPager[] = {
 
 struct binding_t OpAttach[] = {
   { "bounce-message",	OP_BOUNCE_MESSAGE,		"b" },
-  { "display-toggle-weed",	OP_DISPLAY_HEADERS,		"h" },
+  { "display-toggle-weed",	OP_DISPLAY_HEADERS,	"h" },
   { "edit-type",	OP_EDIT_TYPE,			"\005" },
   { "print-entry",	OP_PRINT,			"p" },
   { "save-entry",	OP_SAVE,			"s" },
@@ -251,8 +257,8 @@ struct binding_t OpAttach[] = {
   { "view-attach",	OP_VIEW_ATTACH,			M_ENTER_S },
   { "delete-entry",	OP_DELETE,			"d" },
   { "undelete-entry",	OP_UNDELETE,			"u" },
-
-
+  { "collapse-parts",	OP_ATTACH_COLLAPSE,		"v" },
+  
 
 #ifdef HAVE_PGP
   { "extract-keys",	OP_EXTRACT_KEYS,		"\013" },
