@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000 Brendan Cully <brendan@kublai.com>
+ * Copyright (C) 2000-1 Brendan Cully <brendan@kublai.com>
  * 
  *     This program is free software; you can redistribute it and/or modify
  *     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,9 @@
 #include "imap_private.h"
 #include "auth.h"
 
+#include <netinet/in.h>
+#include <netdb.h>
+
 #include <sasl.h>
 #include <saslutil.h>
 
@@ -34,7 +37,7 @@ imap_auth_res_t imap_auth_sasl (IMAP_DATA* idata)
   int rc, irc;
   char buf[LONG_STRING];
   const char* mech;
-  char* pc;
+  char* pc = NULL;
   unsigned int len, olen;
   unsigned char client_start;
 
@@ -53,6 +56,30 @@ imap_auth_res_t imap_auth_sasl (IMAP_DATA* idata)
     return IMAP_AUTH_FAILURE;
   }
 
+  /*** set sasl IP properties, necessary for use with krb4 ***/
+  {
+    struct sockaddr_in local, remote;
+    int r, size;
+
+    size = sizeof(local);
+    r = getsockname(idata->conn->fd, &local, &size);
+    if (r!=0) return IMAP_AUTH_FAILURE;
+
+    size = sizeof(remote);
+    r = getpeername(idata->conn->fd, &remote, &size);
+    if (r!=0) return IMAP_AUTH_FAILURE;
+
+#ifdef SASL_IP_LOCAL
+    r = sasl_setprop(saslconn, SASL_IP_LOCAL, &local);
+    if (r!=0) return IMAP_AUTH_FAILURE;
+#endif
+
+#ifdef SASL_IP_REMOTE
+    r = sasl_setprop(saslconn, SASL_IP_REMOTE, &remote);
+    if (r!=0) return IMAP_AUTH_FAILURE;
+#endif
+  }
+
   /* hack for SASL ANONYMOUS support:
    * 1. Fetch username. If it's "" or "anonymous" then
    * 2. attempt sasl_client_start with only "AUTH=ANONYMOUS" capability
@@ -136,7 +163,7 @@ imap_auth_res_t imap_auth_sasl (IMAP_DATA* idata)
 
       /* sasl_client_st(art|ep) allocate pc with malloc, expect me to 
        * free it */
-      free (pc);
+      safe_free (&pc);
     }
     
     if (olen || rc == SASL_CONTINUE)
@@ -144,6 +171,12 @@ imap_auth_res_t imap_auth_sasl (IMAP_DATA* idata)
       strfcpy (buf + olen, "\r\n", sizeof (buf) - olen);
       mutt_socket_write (idata->conn, buf);
     }
+
+    /* If SASL has errored out, send an abort string to the server */
+    if (rc < 0)
+    {
+      mutt_socket_write (idata->conn, "*\r\n");
+    }
   }
 
   while (irc != IMAP_CMD_DONE)
