@@ -308,7 +308,7 @@ void imap_munge_mbox_name (char *dest, size_t dlen, const char *src)
 
   imap_quote_string (dest, dlen, buf);
 
-  free (buf);
+  safe_free ((void **) &buf);
 }
 
 void imap_unmunge_mbox_name (char *s)
@@ -324,7 +324,7 @@ void imap_unmunge_mbox_name (char *s)
     strncpy (s, buf, strlen (s));
   }
   
-  free (buf);
+  safe_free ((void **) &buf);
 }
 
 /* imap_wordcasecmp: find word a in word list b */
