@@ -105,6 +105,11 @@ static void maildir_parse_flags(HEADER *h, const char *path)
 	
 	h->replied = 1;
 	break;
+
+	case 'T': /* trashed */
+
+	h->deleted = 1;
+	break;
       }
       p++;
     }
@@ -377,13 +382,14 @@ static void maildir_flags (char *dest, size_t destlen, HEADER *hdr)
 {
   *dest = '\0';
   
-  if (hdr && (hdr->flagged || hdr->replied || hdr->read))
+  if (hdr && (hdr->flagged || hdr->replied || hdr->read || hdr->deleted))
   {
     snprintf (dest, destlen, 
-	      ":2,%s%s%s",
+	      ":2,%s%s%s%s",
 	     hdr->flagged ? "F" : "",
 	     hdr->replied ? "R" : "",
-	     hdr->read ? "S" : "");
+	     hdr->read ? "S" : "",
+	     hdr->deleted ? "T" : "");
   }
 }
     
@@ -477,6 +483,9 @@ int maildir_commit_message (CONTEXT *ctx, MESSAGE *msg, HEADER *hdr)
   char full[_POSIX_PATH_MAX];
   char *s;
 
+  if (safe_fclose (&msg->fp) != 0)
+    return -1;
+  
   /* extract the subdir */
   s = strrchr (msg->path, '/') + 1;
   strfcpy (subdir, s, 4);
@@ -529,6 +538,9 @@ int mh_commit_message (CONTEXT *ctx, MESSAGE *msg, HEADER *hdr)
   char path[_POSIX_PATH_MAX];
   char tmp[16];
 
+  if (safe_fclose (&msg->fp) != 0)
+    return -1;
+  
   if ((dirp = opendir (ctx->path)) == NULL)
   {
     mutt_perror (ctx->path);
@@ -596,6 +608,7 @@ static int mh_sync_message (CONTEXT *ctx, int msgno)
   MESSAGE *dest;
 
   int rc;
+  short restore = 1;
   char oldpath[_POSIX_PATH_MAX];
   char newpath[_POSIX_PATH_MAX];
   char partpath[_POSIX_PATH_MAX];
@@ -621,7 +634,10 @@ static int mh_sync_message (CONTEXT *ctx, int msgno)
     mx_close_message (&dest);
 
     if (rc == 0)
+    {
       unlink (oldpath);
+      restore = 0;
+    }
 
     /* 
      * Try to move the new message to the old place.
@@ -645,9 +661,10 @@ static int mh_sync_message (CONTEXT *ctx, int msgno)
 	mutt_str_replace (&h->path, partpath);
     }
   }
-  else mx_close_message (&dest);
+  else 
+    mx_close_message (&dest);
 
-  if (rc == -1)
+  if (rc == -1 && restore)
   {
     h->content->offset = old_body_offset;
     h->content->length = old_body_length;
@@ -725,7 +742,7 @@ int mh_sync_mailbox (CONTEXT * ctx, int *index_hint)
 
   for (i = 0; i < ctx->msgcount; i++)
   {
-    if (ctx->hdrs[i]->deleted)
+    if (ctx->hdrs[i]->deleted && (ctx->magic != M_MAILDIR || !option(OPTMAILDIRTRASH)))
     {
       snprintf (path, sizeof (path), "%s/%s", ctx->path, ctx->hdrs[i]->path);
       if (ctx->magic == M_MAILDIR || (option (OPTMHPURGE) && ctx->magic == M_MH))
