@@ -280,6 +280,12 @@ enum
 #define SENDKEY		(1<<7)
 #define SENDRESEND	(1<<8)
 
+/* flags to _mutt_select_file() */
+#define M_SEL_BUFFY	(1<<0)
+#define M_SEL_MULTI	(1<<1)
+#define M_SEL_FOLDER	(1<<2)
+
+
 /* boolean vars */
 enum
 {
@@ -299,6 +305,7 @@ enum
   OPTCONFIRMAPPEND,
   OPTCONFIRMCREATE,
   OPTDELETEUNTAG,
+  OPTDIGESTCOLLAPSE,
   OPTEDITHDRS,
   OPTENCODEFROM,
   OPTENVFROM,
@@ -418,7 +425,6 @@ enum
 			 * 	    functions while we are executing an
 			 * 	    external program.
 			 */
-  
 #ifdef HAVE_PGP
   OPTPGPCHECKTRUST,	/* (pseudo) used by pgp_select_key () */
   OPTDONTHANDLEPGPKEYS,	/* (pseudo) used to extract PGP keys */
@@ -567,6 +573,7 @@ typedef struct body
   unsigned int goodsig : 1;	/* good PGP signature */
 #endif
 
+  unsigned int collapsed : 1;	/* used by recvattach */
 
 } BODY;
 
