@@ -892,7 +892,7 @@ BODY *pgp_decrypt_part (BODY *a, STATE *s, FILE *fpout)
   {
     len = mutt_strlen (buf);
     if (len > 1 && buf[len - 2] == '\r')
-      strcpy (buf + len - 2, "\n");
+      strcpy (buf + len - 2, "\n");	/* __STRCPY_CHECKED__ */
     fputs (buf, fpout);
   }
 
@@ -1261,7 +1261,7 @@ char *pgp_findKeys (ADDRESS *to, ADDRESS *cc, ADDRESS *bcc)
     
     keylist_size += mutt_strlen (keyID) + 4;
     safe_realloc ((void **)&keylist, keylist_size);
-    sprintf (keylist + keylist_used, "%s0x%s", keylist_used ? " " : "",
+    sprintf (keylist + keylist_used, "%s0x%s", keylist_used ? " " : "",	/* __SPRINTF_CHECKED__ */
 	     keyID);
     keylist_used = mutt_strlen (keylist);
 
@@ -1273,8 +1273,8 @@ char *pgp_findKeys (ADDRESS *to, ADDRESS *cc, ADDRESS *bcc)
   return (keylist);
 }
 
-/* Warning: "a" is no longer free()d in this routine, you need
- * to free() it later.  This is necessary for $fcc_attach. */
+/* Warning: "a" is no longer freed in this routine, you need
+ * to free it later.  This is necessary for $fcc_attach. */
 
 static BODY *pgp_encrypt_message (BODY *a, char *keylist, int sign)
 {
