@@ -590,7 +590,7 @@ void mutt_make_misc_reply_headers (ENVELOPE *env, CONTEXT *ctx,
   if (curenv->real_subj)
   {
     env->subject = safe_malloc (mutt_strlen (curenv->real_subj) + 5);
-    sprintf (env->subject, "Re: %s", curenv->real_subj);
+    sprintf (env->subject, "Re: %s", curenv->real_subj);	/* __SPRINTF_CHECKED__ */
   }
   else
     env->subject = safe_strdup ("Re: your mail");
@@ -736,7 +736,7 @@ generate_body (FILE *tempfp,	/* stream for outgoing message */
   }
   else if (flags & SENDFORWARD)
   {
-    if ((i = query_quadoption (OPT_MIMEFWD, _("Forward MIME encapsulated?"))) == M_YES)
+    if ((i = query_quadoption (OPT_MIMEFWD, _("Forward as attachment?"))) == M_YES)
     {
       BODY *last = msg->content;
 
@@ -909,7 +909,7 @@ ADDRESS *mutt_default_from (void)
   {
     adr = rfc822_new_address ();
     adr->mailbox = safe_malloc (mutt_strlen (Username) + mutt_strlen (fqdn) + 2);
-    sprintf (adr->mailbox, "%s@%s", NONULL(Username), NONULL(fqdn));
+    sprintf (adr->mailbox, "%s@%s", NONULL(Username), NONULL(fqdn));	/* __SPRINTF_CHECKED__ */
   }
   else
   {
@@ -1218,24 +1218,9 @@ ci_send_message (int flags,		/* send mode */
 
 
 #ifdef HAVE_PGP
-  
-  if (! (flags & SENDKEY) && tempfp)
-  {
-
-#endif
-    
-
-
-    fclose (tempfp);
-    tempfp = NULL;
-    
-
-
-#ifdef HAVE_PGP
-    
-  }
-
+  if (! (flags & SENDKEY))
 #endif
+    safe_fclose (&tempfp);
 
 
 
@@ -1604,8 +1589,7 @@ cleanup:
   }
 #endif /* HAVE_PGP */
    
-  if (tempfp)
-    fclose (tempfp);
+  safe_fclose (&tempfp);
   mutt_free_header (&msg);
   
   return rv;
